#!/usr/bin/Rscript --vanilla

##
## Source an R file located in the same directory as this script.
##
source.local <- function(filename, arg.prefix="--file=", quiet=TRUE) {
    args <- commandArgs(trailingOnly=FALSE)
    script.arg <- grep(arg.prefix, args, value=TRUE)
    if (length(script.arg) != 1) {
        stop(paste0('unable to source "', filename, '".'))
    }
    this.file <- substring(script.arg, nchar(arg.prefix) + 1)
    source.file <- file.path(dirname(this.file), filename)
    if (! quiet) {
        cat(paste0('Sourcing "', filename, '" from "', basename(this.file),
                   '".\n'))
    }
    source(source.file)
}

net_cases <- function() {
    fs <- list.files('out', 'net-.*\\.ssv', full.names = TRUE)
    df <- NULL
    for (filename in fs) {
        df <- rbind(df, read.table(filename))
    }
    return(df)
}

attack_rates <- function() {
    fs <- list.files('out', 'attack-.*\\.ssv', full.names = TRUE)
    df <- NULL
    for (filename in fs) {
        df <- rbind(df, read.table(filename))
    }
    df$V1 <- 100 * df$V1
    return(df)
}

##
## Plot the baseline epidemic outcomes.
##
main <- function(args) {
    in.ar <- "baseline-attack-rates.ssv"
    in.nc <- "baseline-net-cases.ssv"
    out.file <- "baseline.pdf"

    source.local("../../bin/theme_rgm.R")

    ar <- read.table(in.ar, header = FALSE)
    nc <- read.table(in.nc, header = FALSE)

    ar$lbl <- 'Baseline'
    nc$lbl <- 'Baseline'

    cat('Max # cases where AR < 10%:', max(nc$V1[ar$V1 < 0.1]), '\n')
    print(sum(nc$V1 < 20) / nrow(nc))
    print(range(ar$V1[nc$V1 > 20]))


    ar2 <- attack_rates()
    ## nc2 <- net_cases()

    ar2$lbl <- 'Intervention'
    ## nc2$lbl <- 'Intervention'

    ar$pcnt <- floor(ar$V1 * 100) + 0.5
    ar$count <- 1
    ar2$pcnt <- floor(ar2$V1) + 0.5
    ar2$count <- 1

    print(sum(ar2$V1 > 0.1 & ar2$V1 < 75) / nrow(ar2))
    print(sum(ar2$V1 > 0.5 & ar2$V1 < 75) / nrow(ar2))
    print(sum(ar2$V1 > 1.0 & ar2$V1 < 75) / nrow(ar2))

    agg_ar <- aggregate(ar$count, by = list(lbl = ar$lbl, pcnt = ar$pcnt),
                        FUN = length)
    agg_ar$freq <- agg_ar$x / sum(agg_ar$x)
    print(head(agg_ar))
    agg_ar2 <- aggregate(ar2$count, by = list(lbl = ar2$lbl, pcnt = ar2$pcnt),
                         FUN = length)
    agg_ar2$freq <- agg_ar2$x / sum(agg_ar2$x)
    print(head(agg_ar2))
    print(unique(agg_ar2$pcnt))
    missing_pcnt <- agg_ar2$pcnt[! agg_ar2$pcnt %in% agg_ar$pcnt]
    agg_ar <- rbind(agg_ar, data.frame(lbl = 'Baseline', pcnt = missing_pcnt,
                                       x = 0, freq = 0))

    agg_ar <- rbind(agg_ar, agg_ar2)

    par1 <- ggplot(agg_ar, aes(x = pcnt, y = freq, colour = lbl, fill = lbl)) +
        geom_bar(stat = 'identity', position = 'dodge') +
        scale_x_continuous(breaks = c(0, 20, 40, 60, 80, 100),
                           limits = c(0, 100)) +
        scale_y_continuous() + # breaks = c()) +
        xlab("Attack Rate (%)") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)

    ## rep_times <- nrow(ar2) / nrow(ar)
    ## ar <- ar[rep(seq_len(nrow(ar)), rep_times), ]

    ## ar <- rbind(ar, ar2)
    ## nc <- rbind(nc, nc2)

    ## par1 <- ggplot(ar, aes(x = 100 * V1, colour = lbl, fill = lbl)) +
    ##     geom_bar(aes(y = (..count..)/sum(..count..)), binwidth = 1, position = 'dodge') +
    ##     scale_x_continuous(breaks = c(0, 20, 40, 60, 80, 100),
    ##                        limits = c(0, 100)) +
    ##     scale_y_continuous() + # breaks = c()) +
    ##     xlab("Attack Rate (%)") +
    ##     ylab(NULL) +
    ##     theme_rgm(axis.black = TRUE)

    CairoPDF(out.file, bg = 'transparent', width = 4.9, height = 3.6)
    print(par1)
    invisible(dev.off())
    return(NULL)

    p <- ggplot(ar, aes(x = AR)) +
        geom_bar(binwidth = 1) +
        scale_x_continuous(breaks = c(0, 20, 40, 60, 80), limits = c(0, 80)) +
        scale_y_continuous(breaks = c()) +
        xlab("Attack Rate (%)") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)
    p2 <- ggplot(ar, aes(x = AR)) +
        geom_bar(binwidth = 0.01) +
        scale_x_continuous(breaks = c(0, 0.2, 0.4, 0.6, 0.8, 1),
                           limits = c(0, 1)) +
        scale_y_continuous(breaks = c()) +
        xlab("Attack Rate (%)") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)
    p3 <- ggplot(ar, aes(x = AR)) +
        geom_bar(binwidth = 0.001) +
        scale_x_continuous(limits = c(0, 0.1)) +
        scale_y_continuous(breaks = c()) +
        xlab("Attack Rate (%)") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)
    CairoPDF('attack-rate.pdf', bg = 'transparent', width = 4.9, height = 3.6)
    print(p)
    print(p2)
    print(p3)
    invisible(dev.off())

    nc <- net_cases(data.dir)
    p <- ggplot(nc, aes(x = cases)) +
        geom_bar(binwidth = 10) +
        scale_x_continuous(limits = c(0, 1000)) +
        scale_y_continuous(breaks = c()) +
        xlab("Final Size") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)
    p2 <- ggplot(nc, aes(x = cases)) +
        geom_bar(binwidth = 1) +
        scale_x_continuous(limits = c(0, 100)) +
        scale_y_continuous(breaks = c()) +
        xlab("Final Size") +
        ylab(NULL) +
        theme_rgm(axis.black = TRUE)
    CairoPDF('final-size.pdf', bg = 'transparent', width = 4.9, height = 3.6)
    print(p)
    print(p2)
    invisible(dev.off())
}

##
## Only call main() if this script is being run from the command-line.
##
if (! interactive()) {
    file.arg <- grep("^--file=", commandArgs(FALSE), value = TRUE)
    if (grepl("plot-baseline.R", file.arg)) {
        invisible(main(args = commandArgs(TRUE)))
    }
}
