#!/usr/bin/Rscript --vanilla

library(rhdf5)
library(ggplot2)

source(file.path("..", "..", "bin", "theme_rgm.R"))

cat('Loading data series ... ')
series <- h5read('data-series.hdf5', '/output/all')
cat('done\n')

models <- 1000

Inc <- series$I0c + series$I0h + series$I0t + series$Ic + series$Ih +
    series$Qc + series$Qh + series$Hc + series$Hh +
    series$Ec + series$Eh + series$Et
Inc <- matrix(Inc, nrow = models)

CumI <- matrix(series$CumI, nrow = models)
CumI <- CumI[, ncol(CumI)]

die_ixs <- which(CumI < 16)
ctl_ixs <- which(CumI > 16 & CumI < 50)
unc_ixs <- which(CumI > 1000)

df <- data.frame(
    t = 1:ncol(Inc) / 7,
    i = c(Inc[die_ixs[1], ], Inc[ctl_ixs[1], ], Inc[unc_ixs[1], ]),
    l = rep(c('Die-Out', 'Controlled', 'Uncontrolled'), each = ncol(Inc)))

cat('Final sizes:\n')
cat('  ', CumI[c(die_ixs[1], ctl_ixs[1], unc_ixs[1])], '\n')

df <- df[df$t <= 25, ]

clrs <- c("#FFAA00", "#006A00", "#FF0000")
brks <- c('Die-Out', 'Controlled', 'Uncontrolled')
lbls <- c(paste0('Die-Out (n = ', CumI[die_ixs[1]], ')'),
          paste0('Controlled (n = ', CumI[ctl_ixs[1]], ')'),
          'Uncontrolled')

p <- ggplot(df, aes(x = t, y = i, colour = l)) +
    geom_line() +
    scale_colour_manual("", breaks = brks, values = clrs, labels = lbls) +
    ylab("Prevalence") +
    xlab("Time (weeks)") +
    scale_x_continuous(expand = c(0, 0)) +
    scale_y_continuous(expand = c(0, 0), limits = c(0, max(df$i) + 1)) +
    theme_rgm(axis.black = TRUE)

CairoPDF('time-series.pdf', bg = 'transparent', width = 7.4, height = 4.8)
print(p)
invisible(dev.off())
