#!/usr/bin/Rscript --vanilla

suppressPackageStartupMessages(library(ggplot2))
suppressPackageStartupMessages(library(themergm))
suppressPackageStartupMessages(library(Cairo))

build_df <- function(nb_disp, mu, xs) {
    df0 <- expand.grid(x = xs, mu = mu)

    df_p <- df0
    df_p$y <- dpois(df_p$x, df_p$mu)
    df_p$dist <- 'Poisson'

    df_n <- df0
    df_n$y <- dnbinom(df_n$x, size = nb_disp, mu = df_n$mu)
    df_n$dist <- 'NB'

    df <- rbind(df_p, df_n)
    df$nb_disp <- nb_disp

    return(df)
}

cmp_nbinom_dist <- function(disp, mu = c(1, 2, 5, 10, 20, 50), xs = 0:100) {
    lbls <- sapply(mu, function(x) bquote(E*group("[", x, "]") == .(x)))

    df <- NULL
    for (k in disp) {
        df <- rbind(df, build_df(k, mu, xs))
    }

    df$mu <- factor(df$mu)

    df$nb_disp_lbl <- paste("k =", df$nb_disp)

    p <- ggplot(df, aes(x, y, colour = mu, linetype = dist)) +
        geom_line(size = 0.75) +
        xlab("k") +
        ylab(expression(P(x == k))) +
        scale_colour_hue(NULL, breaks = mu, labels = lbls) +
        scale_linetype_discrete(NULL, guide = 'none') +
        facet_wrap(~ nb_disp_lbl) +
        theme_rgm(legend.position = c(1, 1)) +
        theme(legend.position = "top")

    return(p)
}

p <- cmp_nbinom_dist(c(0.01, 1, 10, 100), mu = c(1, 2, 5, 20), xs = 0:40)
CairoPDF('cmp-nbinom-dist.pdf', width = 12, height = 8)
print(p)
invisible(dev.off())
