#!/usr/bin/env python

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand
import sys

import pybola


# This allows "python setup.py test" to work correctly.
# See https://pytest.org/latest/goodpractises.html for details.
class PyTest(TestCommand):
    description = "Run unit tests using pytest"
    user_options = []

    def initialize_options(self):
        TestCommand.initialize_options(self)

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_suite = True

    def run_tests(self):
        import pytest
        errcode = pytest.main(self.test_args)
        sys.exit(errcode)


setup(
    name=pybola.__package_name__,
    version=pybola.__version__,
    description='Stochastic meta-population model of Ebola transmission',
    license='BSD 3-Clause License',
    author='Rob Moss',
    author_email='rgmoss@unimelb.edu.au',
    packages=find_packages(),
    install_requires=[
        'numpy >= 1.8',
        'scipy >= 0.14',
        'h5py >= 2.0',
    ],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Topic :: Scientific/Engineering :: Mathematics'
    ],
    test_suite='pybola/test',
    tests_require=['pytest'],
    cmdclass={
        'test': PyTest,
    },
)
